@@ -6,6 +6,13 @@
 // [[Rcpp::depends(RcppParallel)]]
 #include <RcppParallel.h>
 
+/*
+ * Check if dots are missing values without evaluating
+ * @param env environment
+ * @return SEXP (LGLEXP)
+ */
+SEXP check_missing_dots(const SEXP env);
+
 /*
  * Calculate vector indices in array
  * @param ptr iterator where to save the calculated array indices to
